@@ -8,3 +8,6 @@
 #undef GETTEXT_PACKAGE
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
+
+/*Always define if getaddrinfo() is defined on the system.*/
+#undef HAVE_GETADDRINFO
