@@ -124,32 +124,31 @@ const char *
 bonobo_activation_hostname_get (void)
 {
 	static char *hostname = NULL;
-	char ha_tmp[4], hn_tmp[65];
-	struct hostent *hent;
+	char hn_tmp[128];
 
 	if (!hostname) {
-		gethostname (hn_tmp, sizeof (hn_tmp) - 1);
-
-		hent = gethostbyname (hn_tmp);
-		if (hent) {
-			memcpy (ha_tmp, hent->h_addr, 4);
-			hent = gethostbyaddr (ha_tmp, 4, AF_INET);
-			if (hent)
-				hostname = g_strdup (hent->h_name);
-			else
-				hostname =
-					g_strdup (inet_ntoa
-						  (*
-						   ((struct in_addr *)
-						    ha_tmp)));
-		} else
-			hostname = g_strdup (hn_tmp);
+                if (!gethostname (hn_tmp, sizeof (hn_tmp) - 1))
+                        hostname = g_strdup (hn_tmp);
+                else
+                        hostname = g_strdup ("localhost");
 	}
 
 	return hostname;
 }
 
 
+/**
+ * bonobo_activation_context_get:
+ * @void: 
+ * 
+ * Fetches the internal CORBA_Context used with every activation
+ * request. This can be used to manipulate some of the associated
+ * fields; particularly 'display'.
+ *
+ * This method is deprecated.
+ * 
+ * Return value: the CORBA context for activating with.
+ **/
 CORBA_Context
 bonobo_activation_context_get (void)
 {
@@ -257,7 +256,6 @@ struct poptOption bonobo_activation_popt_options[] = {
  * 
  * Return value: The IID of the activated server or NULL.
  */
-
 const char *
 bonobo_activation_iid_get (void)
 {
@@ -326,7 +324,6 @@ bonobo_activation_is_initialized (void)
  * 
  * Return value: A localized copy of the string "bonobo activation options"
  */
-
 char *
 bonobo_activation_get_popt_table_name (void)
 {
@@ -384,6 +381,16 @@ bonobo_activation_init (int argc, char **argv)
 	return retval;
 }
 
+/**
+ * bonobo_activation_orb_init:
+ * @argc: pointer to program's argument count
+ * @argv: argument array
+ * 
+ * Initialize Bonobo Activation's ORB - do this once centrally
+ * so it can be easily shared.
+ * 
+ * Return value: the ORB.
+ **/
 CORBA_ORB
 bonobo_activation_orb_init (int *argc, char **argv)
 {
